@@ -97,7 +97,7 @@ class ExternalAuthorizationProvider(object):
 
         # only check for specific medium types, or all if it is set to wildcard (*)
         mediums = self._get_mediums_from_reject_message(message)
-        if "*" not in self.VALID_MEDIUM_TYPES and all(m.medium_type not in self.VALID_MEDIUM_TYPES for m in mediums):
+        if "*" not in self.VALID_MEDIUM_TYPES and all(m.type not in self.VALID_MEDIUM_TYPES for m in mediums):
             return False
 
         return True
@@ -248,7 +248,7 @@ class ExternalAuthorizationProvider(object):
         results: List[ResultEntry] = self._handle_has_access_from_message(message)
         for result in results:
             if result is False:
-                logging.info("id {} not allowed at {}".format(result.medium.id, gate))
+                logging.info("id {} not allowed at {}".format(message.get("id"), gate))
             else:
                 logging.info("id {} allowed at {}".format(result.medium.id, gate))
                 message = Message(
@@ -332,22 +332,25 @@ class ExternalAuthorizationProvider(object):
 
     def run(self):
         self.register()
-        while True:
-            topic, message = Message.from_socket(self.sub)
-            if topic == Topic.ACCESS_REJECT:
-                self._handle_access_reject(message)
-            elif topic == Topic.COUNT:
-                direction = message.get("gateway", {}).get("direction")
-                if direction == "in":
-                    self._handle_count_in(message)
-                elif direction == "out":
-                    self._handle_count_out(message)
-                else:
-                    logging.error("unknown direction {} for message {}".format(direction, message))
-            elif topic == Topic.BACKEND:
-                type = message.get("type", "").lower()
-                if type == "register_request":
-                    self.register()
+        try:
+            while True:
+                topic, message = Message.from_socket(self.sub)
+                if topic == Topic.COUNT:
+                    direction = message.get("gateway", {}).get("direction")
+                    if direction == "in":
+                        self._handle_count_in(message)
+                    elif direction == "out":
+                        self._handle_count_out(message)
+                    else:
+                        logging.error("unknown direction {} for message {}".format(direction, message))
+                elif topic == Topic.BACKEND:
+                    type = message.get("type", "").lower()
+                    if type == "register_request":
+                        self.register()
+        except KeyboardInterrupt:
+            pass
+        except:
+            raise
 
     def register(self):
         message = Message(name=self.config.NAME, type="register")
@@ -361,7 +364,7 @@ class ExternalAuthorizationProvider(object):
             logging.info("id {}-{} not allowed at {}".format(request.get("medium_type"), request.get("id"), gate))
             return {"success": False, "name": self.config.NAME, "gateway": gateway}
         for result in results:
-            if result.access:
+            if result and result.access:
                 logging.info("id {}-{} allowed at {}".format(result.medium.type, result.medium.id, gate))
                 return {
                     "success": True,
